---
title: Welcome to FragmentColor
description: FragmentColor - Cross-platform GPU Programming for Rust, Javascript, Python, Swift, and Kotlin.
template: splash
hero:
  tagline: Easy GPU Programming for Rust, Javascript, Python, Swift, and Kotlin.
  image:
    file: ../../assets/houston.webp
  actions:
    - text: Github
      link: https://github.com/vista-art/fragmentcolor
      icon: github
      variant: primary
    - text: Documentation
      link: /welcome
      icon: document
      variant: secondary
    # - text: Playground
    #   link: /welcome/playground
    #   icon: rocket
    #   variant: secondary
---

import { Code, Tabs, TabItem } from "@astrojs/starlight/components";
import Examples from "../../components/Examples.mdx";

<Examples />
